package com.muyu.enterprise.controller;

import com.muyu.enterprise.cache.AllFaultCacheService;
import com.muyu.enterprise.cache.FaultCacheService;
import com.muyu.enterprise.service.FaultInfoService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;

import com.muyu.domain.FaultInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 故障信息
 */

@Log4j2
@RestController
@Tag(name = "故障管理列", description = "故障管理列")
@RequestMapping("/info")
public class FaultInfoController extends BaseController {

    @Autowired
    private FaultInfoService service;

    @Autowired
    private AllFaultCacheService allFaultCacheService;

    /**
     * 查询车辆故障管理列表
     */
    @GetMapping("/list")
    @RequiresPermissions("fault:fault:list")
    @Operation(summary = "查询集合", description = "查询车辆故障管理列表")
    public Result<TableDataInfo<FaultInfo>> list(FaultInfo faultInfo) {
        startPage();
        List<FaultInfo> list = service.pageQuery(faultInfo);
        allFaultCacheService.put(faultInfo.getFaultCode(),list);
        return getDataTable(list);
    }


    /**
     * 导出车辆故障管理列表
     */
    @Log(title = "车辆故障管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @RequiresPermissions("fault:fault:export")
    public void export(HttpServletResponse response, FaultInfo fault) {
        List<FaultInfo> list = service.pageQuery(fault);
        ExcelUtil<FaultInfo> util = new ExcelUtil<FaultInfo>(FaultInfo.class);
        util.exportExcel(response, list, "车辆故障管理数据");
    }


    /**
     * 获取车辆故障管理详细信息
     */
    @GetMapping(value = "/{id}")
    public Result<String> getConfigKey (@PathVariable("id") String id) {
        return success(service.getById(id));
    }


    /**
     * 新增车辆故障管理
     */
    @Log(title = "车辆故障管理", businessType = BusinessType.INSERT)
    @PostMapping
    @RequiresPermissions("fault:info:add")
    public Result add(@RequestBody FaultInfo faultInfo) {
        service.save(faultInfo);
        //添加的数据存进缓存
//        faultCacheService.put(faultInfo.);
        return Result.success(null, "成功");
    }



    /**
     * 修改车故障管理
     */
    @Log(title = "车辆故障管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @RequiresPermissions("fault:info:edit")
    public Result edit(@RequestBody FaultInfo fault) {
        service.updateById(fault);
        return Result.success(null, "成功");
    }



    /**
     * 删除车辆故障管理
     */
    @Log(title = "车辆故障管理删除", businessType = BusinessType.DELETE)
    @DeleteMapping("/{id}")
    @RequiresPermissions("fault:info:remove")
    public Result remove(@PathVariable("id") Long[] id) {
        return Result.success(service.removeBatchByIds(Arrays.asList(id)), "成功");
    }


}
